import os
import typing

from PIL import Image
import pytest

from pioupiou import FolderAvatarTheme


class TestFolderAvatarTheme(object):
    @pytest.mark.parametrize(
        "folder_path, layers_name, token, saved_file_path, height, width",
        [
            (
                "sample/cat_revoy",
                ["body", "fur", "eyes", "mouth", "accessorie"],
                "just a random string",
                "/tmp/saved_cat_avatar.png",
                256,
                256,
            ),
            (
                "sample/bird_revoy",
                ["tail", "hoop", "body", "wing", "eyes", "bec", "accessorie"],
                "just a random string",
                "/tmp/saved_bird_avatar.png",
                256,
                256,
            ),
            (
                "sample/monster_id",
                ["legs", "hair", "arms", "body", "eyes", "mouth"],
                "just a random string",
                "/tmp/saved_monster_avatar.png",
                120,
                120,
            ),
        ],
    )
    def test_avatar_generation_on_disk(
        self,
        folder_path: str,
        layers_name: typing.List[str],
        token: str,
        saved_file_path: str,
        height: int,
        width: int,
    ):
        theme = FolderAvatarTheme(folder_path=folder_path, layers_name=layers_name)
        avatar = theme.generate_avatar(token=token)
        theme.save_on_disk(avatar, path=saved_file_path)
        assert os.path.exists(saved_file_path) is True
        assert os.path.getsize(saved_file_path) > 0
        with Image.open(saved_file_path) as avatar:
            assert avatar.height == height
            assert avatar.width == width
